@@ -1,16 +1,25 @@
+import os
+
+if os.name == "nt":
+    DEFAULT_EDITOR = "notepad"
+else:
+    DEFAULT_EDITOR = "vi"
+
 CLI_CONFIG = {
     "input_file": {
         "positional": True,
-        "subcommands": ["encrypt", "decrypt"],
+        "nargs": "?",
+        "subcommands": ["encrypt", "decrypt", "edit"],
     },
-    "acct_key": {"subcommands": ["encrypt", "decrypt"]},
-    "acct_file": {"subcommands": ["encrypt", "decrypt"]},
+    "acct_key": {"subcommands": ["encrypt", "decrypt", "edit"]},
+    "acct_file": {"subcommands": ["encrypt", "decrypt", "edit"]},
     "extras": {},
     "overrides": {},
     "render_pipe": {},
-    "crypto_plugin": {"subcommands": ["encrypt", "decrypt"]},
-    "output": {"source": "rend", "subcommands": ["decrypt"]},
-    "output_file": {"subcommands": ["encrypt"]},
+    "crypto_plugin": {"subcommands": ["encrypt", "decrypt", "edit"]},
+    "output": {"source": "rend", "subcommands": ["decrypt", "edit"]},
+    "editor": {"subcommands": ["edit"]},
+    "output_file": {"subcommands": ["encrypt", "edit"]},
 }
 CONFIG = {
     "acct_file": {
@@ -51,11 +60,21 @@ CONFIG = {
         "default": None,
         "help": "A list of backend profile names to allow, defaults to ALL",
     },
+    "output": {"source": "rend", "default": "yaml"},
     "output_file": {"default": None, "help": "The output file name when encrypting"},
+    "editor": {
+        "default": DEFAULT_EDITOR,
+        "help": "The text editor to use",
+        "os": "EDITOR",
+    },
 }
 SUBCOMMANDS = {
     "encrypt": {x: "Use the acct command to encrypt data" for x in ("desc", "help")},
     "decrypt": {x: "Use the acct command to decrypt data" for x in ("desc", "help")},
+    "edit": {
+        x: "Edit the decrypted contents of the acct_file and save over the original"
+        for x in ("desc", "help")
+    },
 }
 DYNE = {
     "acct": ["acct"],
